@@ -284,7 +284,7 @@ class Bigoyster:
         result = self.call_list_api('tag', params=params).get('results')
         return result
 
-    def create_store_coupon(self, device_id, headline, description, image_b64, customer_ref, categories, callback=''):
+    def create_store_coupon(self, device_id, headline, description, image_b64, customer_ref, categories, callback='', selected_periods=[]):
         if not device_id:
             raise Exception('NO DEVICE')
         values = {
@@ -296,6 +296,7 @@ class Bigoyster:
                 'image_b64': image_b64,
                 'customer_ref': customer_ref,
                 'categories': categories,
+                'selected_periods': selected_periods,
                 'callback': callback
             }
         }
